/*
    $Id: url.c,v 1.9 2001/04/07 00:09:56 james Exp $

    url, remote control listener to open a url
    Copyright (C) 2000  James Cameron (quozl@us.netrek.org)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*

  Given a file name as the command line argument, this program waits
  for the file to be created, and once it is, uses the first line of
  text in the file as a URL to open a web browser against.

  The check for the file is once every SCANINTERVAL seconds (default
  10).  The use of one second sleeps is to minimise processor
  utilisation and yet provide reasonable response to request to exit.

  The file will only be deleted if a line was found.  The validity of
  the URL in the file is not checked.  It is presumed that the person
  running this program will make it reasonably secure, as it can
  clearly be abused if running in a network environment.

  Credit goes to Patrick Coen <patrick.coen@s1.com> for explaining to
  me the means by which an application participates in the message
  loop.

  Credit also to the Netrek COW win32/mswindow.c module, for showing
  how to use PeekMessage() to avoid a block.  Thanks to Adrian Brightmoore
  for suggesting it.

*/

#include <stdio.h>
#include <windows.h>
#include <winbase.h>
#include <shellapi.h>
#pragma comment(lib,"shell32.lib")

#define MAXSIZE 2048
#define SCANINTERVAL 10

int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR
lpCmdLine, int nCmdShow)
{
  MSG   msg;

  if (strlen(lpCmdLine) == 0) {
    fprintf(stderr, "Prepaid Accounting Listener, 1.0\n"
         "Copyright (C) 2001  James Cameron (quozl@us.netrek.org)\n"
         "\n"
"This program comes with ABSOLUTELY NO WARRANTY; for details see source.\n"
"This is free software, and you are welcome to redistribute it under certain\n"
"conditions; see source for details.\n\n");

    fprintf(stderr, "Usage: ppa_listener file\n");
    fprintf(stderr, "Warning: this program DELETES the file given to it\n");
    return 0;
  }

  memset(&msg, 0, sizeof(msg));
  while(1) {
    static int timer = 0;
    int lines = 0;
    FILE *file;

    if (PeekMessage(&msg, NULL, 0, 0, PM_REMOVE) != 0) {
      return 0;
    }
    sleep(1);
    if (++timer > SCANINTERVAL) {
      timer = 0;
      file = fopen(lpCmdLine, "r");
      if (file != NULL) {
	char buffer[MAXSIZE];
	lines = 0;
	if (fgets(buffer, MAXSIZE, file) != NULL) {
	  ShellExecute(NULL,"open",buffer, "", "c:\\", SW_SHOWNORMAL);
	  lines++;
	}
	fclose(file);
	if (lines > 0) unlink(lpCmdLine);
      }
    }
  }
}

